@@ -1,11 +1,11 @@
-# $Id: SetUser.pm 19 2008-05-08 23:24:58Z dmartin $
+# $Id$
 
 package Unix::SetUser;
 
 use warnings;
 use strict;
 use Carp;
-use Unix::SavedIDs "0.4.0";
+use Unix::SavedIDs 0.004002;
 use Data::Dumper;
 
 #warn "\@INC = ".join(" ",@INC)."\n";
@@ -20,7 +20,7 @@ BEGIN {
 	our ($VERSION,@ISA,@EXPORT);
 	@ISA    = qw(Exporter);
 	@EXPORT = qw(set_user);
-	use version; $VERSION = qv('0.4.0');
+	$VERSION = 0.004003;
 }
 
 sub set_user {
